# frozen_string_literal: true

require_dependency 'commissionwork/application_controller'

module Commissionwork
  class UsersController < ApplicationController
    before_action :set_user, only: %i[show update destroy]

    def index
      @user = User.all
      @user_list = @user.map do |u|
        {
          code: '200',
          id: u.id,
          firstName: u.firstName,
          lastName: u.lastName,
          userName: u.userName,
          phoneNumber: u.phoneNumber,
          userRole: u.userRole
        }
      end
      unless @user_list.empty?
        render json: { data: @user_list, status: 'success' }, status: 200
      end
    end

    def show
      @one_user = @user.tap do |u|
        { code: '200',
          id: u.id, firstName: u.firstName,
          lastName: u.lastName,
          userName: u.userName,
          phoneNumber: u.phoneNumber,
          userRole: u.userRole }
      end
      render json: { data: @one_user, status: 'success' }, status: 200
    end

    def create
      @user = User.new(user_params)
      if @user.save
        @new_user = @user.tap do |u|
          { code: '200',
            id: u.id, firstName: u.firstName,
            lastName: u.lastName, userName: u.userName,
            phoneNumber: u.phoneNumber, userRole: u.userRole }
        end
        render json: { data: @new_user, status: 'success' }, status: 200
      else
        render json: { data: { code: '404', message: @user.errors }, status: 'fail' },
               status: 400
      end
    end

    def update
      if @user.update(user_params)
        render json: { data: @user, status: 'success' }, status: 200
      else
        render json: { data: { code: '400', message: @user.errors } }, status: 200
      end
    end

    def destroy
      @user.destroy
    end

    private

    def set_user
      @user = User.find(params[:id])
    end

    def user_params
      params.require(:user).permit(:firstName, :lastName, :userName, :phoneNumber, :userRole)
    end
  end
end
