# frozen_string_literal: true

module Commissionwork
  class Subscription < ApplicationRecord
    belongs_to :commissionwork_users, class_name: 'Commissionwork::User'
    validates :subscriptionStartDate, :subscriptionEndDate, :subscriptionMethod,
              :subscriptionStatus, presence: true
    validate :end_date_cannot_be_in_the_past
    validate :end_date_before_start_date

    def end_date_cannot_be_in_the_past
      subscriptionEndDate.present? && subscriptionEndDate < DateTime.current
      errors.add(:subscriptionEndDate, "can't be in the past")
    end

    def end_date_before_start_date
      subscriptionStartDate.present? && subscriptionEndDate.present? && subscriptionEndDate < subscriptionStartDate
      errors.add(:subscriptionEndDate, 'end date must be after start date')
    end
  end
end
